==> deepin-movie-reborn_5.0.0.orig.tar.gz: deepin-movie-reborn-5.0.0/src/widgets/notification_widget.h <==
/* 
 * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef _DMR_NOTIFICATION_WIDGET_H
#define _DMR_NOTIFICATION_WIDGET_H 

#include <QtWidgets>

#include <DBlurEffectWidget>

DWIDGET_USE_NAMESPACE

namespace dmr {

class NotificationWidget: public QFrame {
    Q_OBJECT
public:
    enum MessageAnchor {
        AnchorNone,
        AnchorBottom,
        AnchorNorthWest
    };
    NotificationWidget(QWidget *parent = 0);
    void setAnchor(MessageAnchor ma) { _anchor = ma; }
    void setAnchorDistance(int v) { _anchorDist = v; }
    void setAnchorPoint(const QPoint& p) { _anchorPoint = p; }

public slots:
    void popupWithIcon(const QString& msg, const QPixmap&);
    void popup(const QString& msg);
    void updateWithMessage(const QString& newMsg);

protected:
    void showEvent(QShowEvent *event) override;
    void resizeEvent(QResizeEvent *re) override;
    void paintEvent(QPaintEvent* pe) override;

private:
    QWidget *_mw {nullptr};
    QLabel *_msgLabel {nullptr};
    QLabel *_icon {nullptr};
    QTimer *_timer {nullptr};
    QFrame *_frame {nullptr};
    QHBoxLayout *_layout {nullptr};
    MessageAnchor _anchor {AnchorNone};
    int _anchorDist {10};
    QPoint _anchorPoint;

    void syncPosition();
};

}

#endif /* ifndef _DMR_NOTIFICATION_WIDGET_H */

==> deepin-movie-reborn_5.7.6.147.orig.tar.gz: deepin-movie-reborn-5.7.6.147/src/widgets/notification_widget.h <==
/* 
 * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef _DMR_NOTIFICATION_WIDGET_H
#define _DMR_NOTIFICATION_WIDGET_H 

#include <QtWidgets>

#include <DBlurEffectWidget>
#include <DGuiApplicationHelper>

DWIDGET_USE_NAMESPACE

namespace dmr {

class NotificationWidget: public QFrame {
    Q_OBJECT
public:
    enum MessageAnchor {
        AnchorNone,
        AnchorBottom,
        AnchorNorthWest
    };
    NotificationWidget(QWidget *parent = 0);
    void setAnchor(MessageAnchor ma) { _anchor = ma; }
    void setAnchorDistance(int v) { _anchorDist = v; }
    void setAnchorPoint(const QPoint& p) { _anchorPoint = p; }

public slots:
    void popupWithIcon(const QString& msg, const QPixmap&);
    void popup(const QString& msg, bool flag = true);
    void updateWithMessage(const QString& newMsg, bool flag = true);
    void syncPosition();
    void syncPosition(QRect rect);
protected:
    void showEvent(QShowEvent *event) override;
    void resizeEvent(QResizeEvent *re) override;
    void paintEvent(QPaintEvent* pe) override;

private:
    QWidget *_mw {nullptr};
    QLabel *_msgLabel {nullptr};
    QLabel *_icon {nullptr};
    QTimer *_timer {nullptr};
    QFrame *_frame {nullptr};
    QHBoxLayout *_layout {nullptr};
    MessageAnchor _anchor {AnchorNone};
    int _anchorDist {10};
    QPoint _anchorPoint;
    bool m_isWheel {true};
};

}

#endif /* ifndef _DMR_NOTIFICATION_WIDGET_H */
